'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._6362 import AbstractAssemblyCompoundCriticalSpeedAnalysis
    from ._6363 import AbstractShaftCompoundCriticalSpeedAnalysis
    from ._6364 import AbstractShaftOrHousingCompoundCriticalSpeedAnalysis
    from ._6365 import AbstractShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6366 import AGMAGleasonConicalGearCompoundCriticalSpeedAnalysis
    from ._6367 import AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6368 import AGMAGleasonConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6369 import AssemblyCompoundCriticalSpeedAnalysis
    from ._6370 import BearingCompoundCriticalSpeedAnalysis
    from ._6371 import BeltConnectionCompoundCriticalSpeedAnalysis
    from ._6372 import BeltDriveCompoundCriticalSpeedAnalysis
    from ._6373 import BevelDifferentialGearCompoundCriticalSpeedAnalysis
    from ._6374 import BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis
    from ._6375 import BevelDifferentialGearSetCompoundCriticalSpeedAnalysis
    from ._6376 import BevelDifferentialPlanetGearCompoundCriticalSpeedAnalysis
    from ._6377 import BevelDifferentialSunGearCompoundCriticalSpeedAnalysis
    from ._6378 import BevelGearCompoundCriticalSpeedAnalysis
    from ._6379 import BevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6380 import BevelGearSetCompoundCriticalSpeedAnalysis
    from ._6381 import BoltCompoundCriticalSpeedAnalysis
    from ._6382 import BoltedJointCompoundCriticalSpeedAnalysis
    from ._6383 import ClutchCompoundCriticalSpeedAnalysis
    from ._6384 import ClutchConnectionCompoundCriticalSpeedAnalysis
    from ._6385 import ClutchHalfCompoundCriticalSpeedAnalysis
    from ._6386 import CoaxialConnectionCompoundCriticalSpeedAnalysis
    from ._6387 import ComponentCompoundCriticalSpeedAnalysis
    from ._6388 import ConceptCouplingCompoundCriticalSpeedAnalysis
    from ._6389 import ConceptCouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6390 import ConceptCouplingHalfCompoundCriticalSpeedAnalysis
    from ._6391 import ConceptGearCompoundCriticalSpeedAnalysis
    from ._6392 import ConceptGearMeshCompoundCriticalSpeedAnalysis
    from ._6393 import ConceptGearSetCompoundCriticalSpeedAnalysis
    from ._6394 import ConicalGearCompoundCriticalSpeedAnalysis
    from ._6395 import ConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6396 import ConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6397 import ConnectionCompoundCriticalSpeedAnalysis
    from ._6398 import ConnectorCompoundCriticalSpeedAnalysis
    from ._6399 import CouplingCompoundCriticalSpeedAnalysis
    from ._6400 import CouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6401 import CouplingHalfCompoundCriticalSpeedAnalysis
    from ._6402 import CVTBeltConnectionCompoundCriticalSpeedAnalysis
    from ._6403 import CVTCompoundCriticalSpeedAnalysis
    from ._6404 import CVTPulleyCompoundCriticalSpeedAnalysis
    from ._6405 import CycloidalAssemblyCompoundCriticalSpeedAnalysis
    from ._6406 import CycloidalDiscCentralBearingConnectionCompoundCriticalSpeedAnalysis
    from ._6407 import CycloidalDiscCompoundCriticalSpeedAnalysis
    from ._6408 import CycloidalDiscPlanetaryBearingConnectionCompoundCriticalSpeedAnalysis
    from ._6409 import CylindricalGearCompoundCriticalSpeedAnalysis
    from ._6410 import CylindricalGearMeshCompoundCriticalSpeedAnalysis
    from ._6411 import CylindricalGearSetCompoundCriticalSpeedAnalysis
    from ._6412 import CylindricalPlanetGearCompoundCriticalSpeedAnalysis
    from ._6413 import DatumCompoundCriticalSpeedAnalysis
    from ._6414 import ExternalCADModelCompoundCriticalSpeedAnalysis
    from ._6415 import FaceGearCompoundCriticalSpeedAnalysis
    from ._6416 import FaceGearMeshCompoundCriticalSpeedAnalysis
    from ._6417 import FaceGearSetCompoundCriticalSpeedAnalysis
    from ._6418 import FEPartCompoundCriticalSpeedAnalysis
    from ._6419 import FlexiblePinAssemblyCompoundCriticalSpeedAnalysis
    from ._6420 import GearCompoundCriticalSpeedAnalysis
    from ._6421 import GearMeshCompoundCriticalSpeedAnalysis
    from ._6422 import GearSetCompoundCriticalSpeedAnalysis
    from ._6423 import GuideDxfModelCompoundCriticalSpeedAnalysis
    from ._6424 import HypoidGearCompoundCriticalSpeedAnalysis
    from ._6425 import HypoidGearMeshCompoundCriticalSpeedAnalysis
    from ._6426 import HypoidGearSetCompoundCriticalSpeedAnalysis
    from ._6427 import InterMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6428 import KlingelnbergCycloPalloidConicalGearCompoundCriticalSpeedAnalysis
    from ._6429 import KlingelnbergCycloPalloidConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6430 import KlingelnbergCycloPalloidConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6431 import KlingelnbergCycloPalloidHypoidGearCompoundCriticalSpeedAnalysis
    from ._6432 import KlingelnbergCycloPalloidHypoidGearMeshCompoundCriticalSpeedAnalysis
    from ._6433 import KlingelnbergCycloPalloidHypoidGearSetCompoundCriticalSpeedAnalysis
    from ._6434 import KlingelnbergCycloPalloidSpiralBevelGearCompoundCriticalSpeedAnalysis
    from ._6435 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6436 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6437 import MassDiscCompoundCriticalSpeedAnalysis
    from ._6438 import MeasurementComponentCompoundCriticalSpeedAnalysis
    from ._6439 import MountableComponentCompoundCriticalSpeedAnalysis
    from ._6440 import OilSealCompoundCriticalSpeedAnalysis
    from ._6441 import PartCompoundCriticalSpeedAnalysis
    from ._6442 import PartToPartShearCouplingCompoundCriticalSpeedAnalysis
    from ._6443 import PartToPartShearCouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6444 import PartToPartShearCouplingHalfCompoundCriticalSpeedAnalysis
    from ._6445 import PlanetaryConnectionCompoundCriticalSpeedAnalysis
    from ._6446 import PlanetaryGearSetCompoundCriticalSpeedAnalysis
    from ._6447 import PlanetCarrierCompoundCriticalSpeedAnalysis
    from ._6448 import PointLoadCompoundCriticalSpeedAnalysis
    from ._6449 import PowerLoadCompoundCriticalSpeedAnalysis
    from ._6450 import PulleyCompoundCriticalSpeedAnalysis
    from ._6451 import RingPinsCompoundCriticalSpeedAnalysis
    from ._6452 import RingPinsToDiscConnectionCompoundCriticalSpeedAnalysis
    from ._6453 import RollingRingAssemblyCompoundCriticalSpeedAnalysis
    from ._6454 import RollingRingCompoundCriticalSpeedAnalysis
    from ._6455 import RollingRingConnectionCompoundCriticalSpeedAnalysis
    from ._6456 import RootAssemblyCompoundCriticalSpeedAnalysis
    from ._6457 import ShaftCompoundCriticalSpeedAnalysis
    from ._6458 import ShaftHubConnectionCompoundCriticalSpeedAnalysis
    from ._6459 import ShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6460 import SpecialisedAssemblyCompoundCriticalSpeedAnalysis
    from ._6461 import SpiralBevelGearCompoundCriticalSpeedAnalysis
    from ._6462 import SpiralBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6463 import SpiralBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6464 import SpringDamperCompoundCriticalSpeedAnalysis
    from ._6465 import SpringDamperConnectionCompoundCriticalSpeedAnalysis
    from ._6466 import SpringDamperHalfCompoundCriticalSpeedAnalysis
    from ._6467 import StraightBevelDiffGearCompoundCriticalSpeedAnalysis
    from ._6468 import StraightBevelDiffGearMeshCompoundCriticalSpeedAnalysis
    from ._6469 import StraightBevelDiffGearSetCompoundCriticalSpeedAnalysis
    from ._6470 import StraightBevelGearCompoundCriticalSpeedAnalysis
    from ._6471 import StraightBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6472 import StraightBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6473 import StraightBevelPlanetGearCompoundCriticalSpeedAnalysis
    from ._6474 import StraightBevelSunGearCompoundCriticalSpeedAnalysis
    from ._6475 import SynchroniserCompoundCriticalSpeedAnalysis
    from ._6476 import SynchroniserHalfCompoundCriticalSpeedAnalysis
    from ._6477 import SynchroniserPartCompoundCriticalSpeedAnalysis
    from ._6478 import SynchroniserSleeveCompoundCriticalSpeedAnalysis
    from ._6479 import TorqueConverterCompoundCriticalSpeedAnalysis
    from ._6480 import TorqueConverterConnectionCompoundCriticalSpeedAnalysis
    from ._6481 import TorqueConverterPumpCompoundCriticalSpeedAnalysis
    from ._6482 import TorqueConverterTurbineCompoundCriticalSpeedAnalysis
    from ._6483 import UnbalancedMassCompoundCriticalSpeedAnalysis
    from ._6484 import VirtualComponentCompoundCriticalSpeedAnalysis
    from ._6485 import WormGearCompoundCriticalSpeedAnalysis
    from ._6486 import WormGearMeshCompoundCriticalSpeedAnalysis
    from ._6487 import WormGearSetCompoundCriticalSpeedAnalysis
    from ._6488 import ZerolBevelGearCompoundCriticalSpeedAnalysis
    from ._6489 import ZerolBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6490 import ZerolBevelGearSetCompoundCriticalSpeedAnalysis
